@@ -12,7 +12,7 @@ use Data::Section::Simple 'get_data_section';
 use File::Temp ();
 use File::Which; # For which().
 
-use Hash::FieldHash ':all';
+use Moo;
 
 use IPC::Run3; # For run3().
 
@@ -20,22 +20,175 @@ use Set::Array;
 
 use Try::Tiny;
 
-fieldhash my %command          => 'command';
-fieldhash my %dot_input        => 'dot_input';
-fieldhash my %dot_output       => 'dot_output';
-fieldhash my %edge             => 'edge';
-fieldhash my %edge_hash        => 'edge_hash';
-fieldhash my %global           => 'global';
-fieldhash my %graph            => 'graph';
-fieldhash my %logger           => 'logger';
-fieldhash my %node             => 'node';
-fieldhash my %node_hash        => 'node_hash';
-fieldhash my %scope            => 'scope';
-fieldhash my %subgraph         => 'subgraph';
-fieldhash my %verbose          => 'verbose';
-fieldhash my %valid_attributes => 'valid_attributes';
+has command =>
+(
+	default  => sub{return Set::Array -> new},
+	is       => 'rw',
+#	isa      => 'Set::Array',
+	required => 0,
+);
 
-our $VERSION = '2.15';
+has dot_input =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+#	isa      => 'Str',
+	required => 0,
+);
+
+has dot_output =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+#	isa      => 'Str',
+	required => 0,
+);
+
+has edge =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+#	isa      => 'HashRef',
+	required => 0,
+);
+
+has edge_hash =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+#	isa      => 'HashRef',
+	required => 0,
+);
+
+has global =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+#	isa      => 'HashRef',
+	required => 0,
+);
+
+has graph =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+#	isa      => 'HashRef',
+	required => 0,
+);
+
+has logger =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+#	isa      => 'Str',
+	required => 0,
+);
+
+has node =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+#	isa      => 'HashRef',
+	required => 0,
+);
+
+has node_hash =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+#	isa      => 'HashRef',
+	required => 0,
+);
+
+has scope =>
+(
+	default  => sub{return Set::Array -> new},
+	is       => 'rw',
+#	isa      => 'Set::Array',
+	required => 0,
+);
+
+has subgraph =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+#	isa      => 'HashRef',
+	required => 0,
+);
+
+has verbose =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+#	isa      => 'Int',
+	required => 0,
+);
+
+has valid_attributes =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+#	isa      => 'HashRef',
+	required => 0,
+);
+
+our $VERSION = '2.16';
+
+# -----------------------------------------------
+
+sub BUILD
+{
+	my($self)    = @_;
+	my($options) = $self -> global;
+	my($dot)     = which('dot');
+	my($global)  =
+	{
+		directed     => $$options{directed} ? 'digraph' : 'graph',
+		driver       => $dot,
+		format       => 'svg',
+		label        => $$options{directed} ? '->' : '--',
+		name         => $$options{name} ? $$options{name} : 'Perl',
+		record_shape => ($$options{record_shape} && $$options{record_shape} =~ /^(M?record)$/) ? $1 : 'Mrecord',
+		strict       => 0,
+		timeout      => 10,
+	};
+
+	for my $key (sort keys %$global)
+	{
+		print "$key => $$global{$key}. \n";
+	}
+
+	$self -> global($global);
+	$self -> load_valid_attributes;
+	$self -> validate_params('global',   %{$self -> global});
+	$self -> validate_params('graph',    %{$self -> graph});
+	$self -> validate_params('node',     %{$self -> node});
+	$self -> validate_params('edge',     %{$self -> edge});
+	$self -> validate_params('subgraph', %{$self -> subgraph});
+	$self -> scope -> push
+		({
+			edge     => $self -> edge,
+			graph    => $self -> graph,
+			node     => $self -> node,
+			subgraph => $self -> subgraph,
+		 });
+
+	my(%global) = %{$self -> global};
+
+	$self -> log(debug => "Default global: $_ => $global{$_}") for sort keys %global;
+
+	my($command) = (${$self -> global}{strict} ? 'strict ' : '')
+		. (${$self -> global}{directed} . ' ')
+		. ${$self -> global}{name}
+		. "\n{\n";
+
+	$self -> command -> push($command);
+
+	$self -> default_graph;
+	$self -> default_node;
+	$self -> default_edge;
+
+} # End of BUILD.
 
 # -----------------------------------------------
 
@@ -335,68 +488,6 @@ sub escape_some_chars
 
 # -----------------------------------------------
 
-sub _init
-{
-	my($self, $arg)             = @_;
-	$$arg{command}              = Set::Array -> new;
-	$$arg{dot_input}            = '';
-	$$arg{dot_output}           = '';
-	$$arg{edge}                 ||= {}; # Caller can set.
-	$$arg{edge_hash}            = {};
-	$$arg{global}               ||= {}; # Caller can set.
-	$$arg{global}{directed}     = $$arg{global}{directed} ? 'digraph' : 'graph';
-	$$arg{global}{driver}       ||= which('dot');
-	$$arg{global}{format}       ||= 'svg';
-	$$arg{global}{label}        ||= $$arg{global}{directed} eq 'digraph' ? '->' : '--';
-	$$arg{global}{name}         ||= 'Perl';
-	$$arg{global}{record_shape} = $$arg{global}{record_shape} && $$arg{global}{record_shape} =~ /^(M?record)$/ ? $1 : 'Mrecord';
-	$$arg{global}{strict}       ||= 0;
-	$$arg{global}{timeout}      ||= 10;
-	$$arg{graph}                ||= {}; # Caller can set.
-	$$arg{logger}               ||= ''; # Caller can set.
-	$$arg{node}                 ||= {}; # Caller can set.
-	$$arg{node_hash}            = {};
-	$$arg{scope}                = Set::Array -> new;
-	$$arg{subgraph}             ||= {}; # Caller can set.
-	$$arg{valid_attributes}     = {};
-	$$arg{verbose}              ||= 0;  # Caller can set.
-	$self                       = from_hash($self, $arg);
-
-	$self -> load_valid_attributes;
-	$self -> validate_params('global',   %{$self -> global});
-	$self -> validate_params('graph',    %{$self -> graph});
-	$self -> validate_params('node',     %{$self -> node});
-	$self -> validate_params('edge',     %{$self -> edge});
-	$self -> validate_params('subgraph', %{$self -> subgraph});
-	$self -> scope -> push
-		({
-			edge     => $self -> edge,
-			graph    => $self -> graph,
-			node     => $self -> node,
-			subgraph => $self -> subgraph,
-		 });
-
-	my(%global) = %{$self -> global};
-
-	$self -> log(debug => "Default global: $_ => $global{$_}") for sort keys %global;
-
-	my($command) = (${$self -> global}{strict} ? 'strict ' : '')
-		. (${$self -> global}{directed} . ' ')
-		. ${$self -> global}{name}
-		. "\n{\n";
-
-	$self -> command -> push($command);
-
-	$self -> default_graph;
-	$self -> default_node;
-	$self -> default_edge;
-
-	return $self;
-
-} # End of _init.
-
-# -----------------------------------------------
-
 sub load_valid_attributes
 {
 	my($self) = @_;
@@ -477,18 +568,6 @@ sub log
 
 # -----------------------------------------------
 
-sub new
-{
-	my($class, %arg) = @_;
-	my($self)        = bless {}, $class;
-	$self            = $self -> _init(\%arg);
-
-	return $self;
-
-}	# End of new.
-
-# -----------------------------------------------
-
 sub pop_subgraph
 {
 	my($self) = @_;
@@ -642,6 +721,9 @@ sub run
 
 		my($stdout, $stderr);
 
+		# Usage of utf8 here relies on ISO-8859-1 match Unicode for low chars.
+		# It saves me the effort of determining if the input contains Unicode.
+
 		run3
 			[$driver, "-T$format"],
 			\$self -> dot_input,
@@ -649,8 +731,8 @@ sub run
 			\$stderr,
 			{
 				binmode_stdin  => ':utf8',
-				binmode_stdout => ':utf8',
-				binmode_stderr => ':utf8',
+				binmode_stdout => ':raw',
+				binmode_stderr => ':raw',
 			};
 
 		die $stderr if ($stderr);
@@ -659,8 +741,7 @@ sub run
 
 		if ($output_file)
 		{
-			open(OUT, '>', $output_file) || die "Can't open(> $output_file): $!";
-			#binmode OUT;
+			open(OUT, '> :raw', $output_file) || die "Can't open(> $output_file): $!";
 			print OUT $stdout;
 			close OUT;
 
@@ -837,7 +918,7 @@ is to provide access to all the latest options available to users of L<Graphviz|
 GraphViz2 V 1 is not backwards compatible with GraphViz V 2, despite the considerable similarity. It was not possible to maintain compatibility
 while extending support to all the latest features of L<Graphviz|http://www.graphviz.org/>.
 
-To ensure L<GraphViz2> is a light-weight module, L<Hash::FieldHash> has been used to provide getters and setters,
+To ensure L<GraphViz2> is a light-weight module, L<Moo> has been used to provide getters and setters,
 rather than L<Moose>.
 
 =head2 What is a Graph?
@@ -1574,19 +1655,19 @@ for details.
 
 =head2 How do I include utf8 characters in labels?
 
-Since V 2.00, L<GraphViz2> incorporates a sample which produce graphs such as L<this|http://savage.net.au/Perl-modules/html/graphviz2/utf8.svg>.
+Since V 2.00, L<GraphViz2> incorporates a sample which produce graphs such as L<this|http://savage.net.au/Perl-modules/html/graphviz2/utf8.1.svg>.
 
-scripts/utf8.pl contains 'use utf8;' because of the utf8 characters embedded in the source code. You will need to do this.
+scripts/utf8.1.pl contains 'use utf8;' because of the utf8 characters embedded in the source code. You will need to do this.
 
 =head2 Why do I get 'Wide character in print...' when outputting to PNG but not SVG?
 
 As of V 2.02, you should not get this from GraphViz2. So, I suggest you study your own code very, very carefully :-(.
 
-Examine the output from scripts/utf8.test.pl, i.e. html/utf8.test.svg and you'll see it's correct. Then run:
+Examine the output from scripts/utf8.2.pl, i.e. html/utf8.2.svg and you'll see it's correct. Then run:
 
-	perl scripts/utf8.test.pl png
+	perl scripts/utf8.2.pl png
 
-and examine html/utf8.test.png and you'll see it matches html/utf8.test.svg in showing 5 deltas. So, I I<think> it's all working.
+and examine html/utf8.2.png and you'll see it matches html/utf8.2.svg in showing 5 deltas. So, I I<think> it's all working.
 
 =head2 How do I print output files?
 
@@ -1769,9 +1850,9 @@ L</logger($logger_object)>.
 The 2 demo programs L</scripts/parse.html.pl> and L</scripts/parse.xml.bare.pl>, which both use L<XML::Bare>, assume your XML has a single
 parent container for all other containers. The programs use this container to provide a name for the root node of the graph.
 
-=head2 Why did you choose L<Hash::FieldHash> over L<Moose>?
+=head2 Why did you choose L<Moo> over L<Moose>?
 
-My policy is to use L<Hash::FieldHash> for stand-alone modules and L<Moose> for applications.
+L<Moo> is light-weight.
 
 =head1 Scripts Shipped with this Module
 
@@ -1792,6 +1873,10 @@ Outputs to ./html/cluster.svg by default.
 
 See also scripts/macro.*.pl below.
 
+=head2 copy.config.pl
+
+End users have no need to run this script.
+
 =head2 scripts/dbi.schema.pl
 
 If the environment vaiables DBI_DSN, DBI_USER and DBI_PASS are set (the latter 2 are optional [e.g. for SQLite]),
@@ -1833,6 +1918,10 @@ Then it extracts the reserved words into ./data/node.shapes.dat.
 Downloads the output formats from L<Graphviz's Output Formats|http://www.graphviz.org/content/output-formats> and outputs them to ./data/output.formats.html.
 Then it extracts the reserved words into ./data/output.formats.dat.
 
+=head2 find.config.pl
+
+End users have no need to run this script.
+
 =head2 scripts/generate.demo.pl
 
 Run by scripts/generate.svg.sh. See next point.
@@ -1843,6 +1932,12 @@ See scripts/generate.svg.sh for details.
 
 Outputs to /tmp by default.
 
+This script is generated by generate.sh.pl.
+
+=head2 generate.sh.pl
+
+Generates scripts/generate.png.sh and scripts/generate.svg.sh.
+
 =head2 scripts/generate.svg.sh
 
 A bash script to run all the scripts and generate the *.svg and *.log files, in ./html.
@@ -1851,6 +1946,8 @@ You can them copy html/*.html and html/*.svg to your web server's doc root, for
 
 Outputs to /tmp by default.
 
+This script is generated by generate.sh.pl.
+
 =head2 scripts/Heawood.pl
 
 Demonstrates the transitive 6-net, also known as Heawood's graph.
@@ -2129,17 +2226,17 @@ Demonstrates a trivial 3-node graph, with colors, just to get you started.
 
 Outputs to ./html/trivial.svg by default.
 
-=head2 scripts/utf8.pl
+=head2 scripts/utf8.1.pl
 
 Demonstrates using utf8 characters in labels.
 
-Outputs to ./html/utf8.svg by default.
+Outputs to ./html/utf8.1.svg by default.
 
-=head2 scripts/utf8.test.pl
+=head2 scripts/utf8.2.pl
 
 Demonstrates using utf8 characters in labels.
 
-Outputs to ./html/utf8.test.svg by default.
+Outputs to ./html/utf8.2.svg by default.
 
 =head1 TODO
 
