@@ -5,13 +5,51 @@ use warnings;
 
 use GraphViz2;
 
-use Hash::FieldHash ':all';
+use Moo;
 
 use XML::Tiny;
 
-fieldhash my %graph => 'graph';
+has graph =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+	#isa     => 'GraphViz2',
+	required => 0,
+);
 
-our $VERSION = '2.15';
+our $VERSION = '2.16';
+
+# -----------------------------------------------
+
+sub BUILD
+{
+	my($self) = @_;
+
+	$self -> graph
+	(
+		GraphViz2 -> new
+		(
+			edge   => {color => 'grey'},
+			global => {directed => 1},
+			graph  => {rankdir => 'TB'},
+			logger => '',
+			node   => {color => 'blue', shape => 'oval'},
+		)
+	);
+
+} # End of BUILD.
+
+# -----------------------------------------------
+
+sub create
+{
+	my($self, %arg) = @_;
+
+	$self -> parse('', 0, XML::Tiny::parsefile($arg{file_name}) );
+
+	return $self;
+
+}	# End of create.
 
 # ------------------------------------------------
 
@@ -38,49 +76,6 @@ sub parse
 
 # -----------------------------------------------
 
-sub create
-{
-	my($self, %arg) = @_;
-
-	$self -> parse('', 0, XML::Tiny::parsefile($arg{file_name}) );
-
-	return $self;
-
-}	# End of create.
-
-# -----------------------------------------------
-
-sub _init
-{
-	my($self, $arg) = @_;
-	$$arg{graph}    ||= GraphViz2 -> new
-		(
-		 edge   => {color => 'grey'},
-		 global => {directed => 1},
-		 graph  => {rankdir => 'TB'},
-		 logger => '',
-		 node   => {color => 'blue', shape => 'oval'},
-		);
-	$self = from_hash($self, $arg);
-
-	return $self;
-
-} # End of _init.
-
-# -----------------------------------------------
-
-sub new
-{
-	my($class, %arg) = @_;
-	my($self)        = bless {}, $class;
-	$self            = $self -> _init(\%arg);
-
-	return $self;
-
-}	# End of new.
-
-# -----------------------------------------------
-
 1;
 
 =pod
@@ -92,21 +87,21 @@ L<GraphViz2::Parse::XML> - Visualize XML as a graph
 =head1 Synopsis
 
 	#!/usr/bin/env perl
-	
+
 	use strict;
 	use warnings;
-	
+
 	use File::Spec;
-	
+
 	use GraphViz2;
 	use GraphViz2::Parse::XML;
-	
+
 	use Log::Handler;
-	
+
 	# ------------------------------------------------
-	
+
 	my($logger) = Log::Handler -> new;
-	
+
 	$logger -> add
 		(
 		 screen =>
@@ -116,7 +111,7 @@ L<GraphViz2::Parse::XML> - Visualize XML as a graph
 			 minlevel       => 'error',
 		 }
 		);
-	
+
 	my($graph) = GraphViz2 -> new
 		(
 		 edge   => {color => 'grey'},
@@ -126,12 +121,12 @@ L<GraphViz2::Parse::XML> - Visualize XML as a graph
 		 node   => {color => 'blue', shape => 'oval'},
 		);
 	my($g) = GraphViz2::Parse::XML -> new(graph => $graph);
-	
+
 	$g -> create(file_name => File::Spec -> catfile('t', 'sample.xml') );
-	
+
 	my($format)      = shift || 'svg';
 	my($output_file) = shift || File::Spec -> catfile('html', "parse.xml.pp.$format");
-	
+
 	$graph -> run(format => $format, output_file => $output_file);
 
 See scripts/parse.xml.pp.pl (L<GraphViz2/Scripts Shipped with this Module>).
